==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/additionalelements/parkingarea/create/length/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# go to additional mode
netedit.additionalMode()

# select parkingArea
netedit.changeElement("parkingArea")

# set invalid height (dummy)
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "dummyLenght")

# try to create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 220, 250)

# set invalid height (empty)
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "")

# try to create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 223, 250)

# set invalid height (negative)
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "-4")

# try to create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 226, 250)

# set valid height
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "3.1")

# create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 229, 250)

# Check undo redo
netedit.undo(referencePosition, 1)
netedit.redo(referencePosition, 1)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/additionalelements/parkingarea/create/length/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to additional mode
netedit.additionalMode()

# select parkingArea
netedit.changeElement("parkingArea")

# set invalid height (dummy)
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "dummyLenght")

# try to create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 475, 256)

# set invalid height (empty)
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "")

# try to create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 475, 256)

# set invalid height (negative)
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "-4")

# try to create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 475, 256)

# set valid height
netedit.changeDefaultValue(netedit.attrs.parkingArea.create.length, "3.1")

# create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 475, 256)

# Check undo redo
netedit.undo(referencePosition, 1)
netedit.redo(referencePosition, 1)

# save netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
